import type { AliyunOssSignature } from '@/types/aliyunOssSignature'
import type { BindParams } from '@/types/bindParams'
import type { PrintersResult } from '@/types/printer'
import type { Spaces } from '@/types/warehouseSpace'
import { http } from '@/utils/http'
import type { Ref } from 'vue'

/**
 * Oss
 */
export const getAliyunOssSignature = () => {
  return http<AliyunOssSignature>({
    method: 'GET',
    url: '/admin/Config/getAliyunOssSignature',
  })
}

/**
 * 打印尾程面单
 */
export const printWaybillLabel = (data: {
  order_no: string
  printer_code: Ref<number, number>
}) => {
  return http<{ express_label: string }>({
    method: 'POST',
    url: '/admin/order.ScanOrder/printWaybillLabel',
    data,
  })
}
/**
 * 称重
 */
export const weigh = (data: { order_no: string; weight: string }) => {
  return http<any>({
    method: 'POST',
    url: '/admin/order.scanOrder/weigh',
    data,
  })
}
/**
 * 出库
 */
export const outStock = (data: { order_no: string; batch_number: string }) => {
  return http<any>({
    method: 'POST',
    url: '/admin/order.scanOrder/outStock',
    data,
  })
}
/**
 * 入库
 */
export const instock = (data: {
  order_no: string
  weight: string
  space_code: string
  is_save_goods: number
  images: any[]
}) => {
  return http<{ express_label: string; msg: string }>({
    method: 'POST',
    url: '/admin/order.scanOrder/instock',
    data,
  })
}
/**
 * 获取 扫描 托盘号、批次号
 */
export const getBindParams = () => {
  return http<BindParams>({
    method: 'GET',
    url: '/admin/order.scanOrder/getBindParams',
  })
}
/**
 * 检查是否存在物品
 * @param order_no 订单号
 */
export const checkWaybillGoods = (order_no: string) => {
  return http<{ is_goods_empty: boolean }>({
    method: 'POST',
    url: '/admin/order.scanOrder/checkWaybillGoods',
    data: { order_no },
  })
}
/**
 * 仓位编码
 * @param code 仓位编码
 */
export const getWarehouseSpace = (code = '') => {
  return http<Spaces>({
    method: 'POST',
    url: '/admin/order.ScanOrder/getWarehouseSpace',
    data: { code },
  })
}
